Package: mashr
Type: Package
Encoding: UTF-8
Title: Multivariate Adaptive Shrinkage
Version: 0.2.79
Date: 2023-10-18
Authors@R: c(person("Matthew","Stephens",role="aut"),
             person("Sarah","Urbut",role="aut"),
             person("Gao","Wang",role="aut"),
             person("Yuxin","Zou",role="aut"),
             person("Yunqi","Yang",role="ctb"),
	     person("Sam","Roweis",role="cph"),
	     person("David","Hogg",role="cph"),
	     person("Jo","Bovy",role="cph"),
             person("Peter","Carbonetto",role=c("aut","cre"),
                    email="peter.carbonetto@gmail.com"))
Description: Implements the multivariate adaptive shrinkage (mash)
    method of Urbut et al (2019) <DOI:10.1038/s41588-018-0268-8> for
    estimating and testing large numbers of effects in many conditions
    (or many outcomes). Mash takes an empirical Bayes approach to
    testing and effect estimation; it estimates patterns of similarity
    among conditions, then exploits these patterns to improve accuracy
    of the effect estimates. The core linear algebra is implemented in
    C++ for fast model fitting and posterior computation.
URL: https://github.com/stephenslab/mashr
BugReports: https://github.com/stephenslab/mashr/issues
License: BSD_3_clause + file LICENSE
Copyright: file COPYRIGHTS
Depends: R (>= 3.3.0), ashr (>= 2.2-22)
Imports: assertthat, utils, stats, plyr, rmeta, Rcpp (>= 1.0.8),
        mvtnorm, abind, softImpute
LinkingTo: Rcpp, RcppArmadillo, RcppGSL (>= 0.3.8)
Suggests: MASS, REBayes, corrplot (>= 0.90), testthat, kableExtra,
        knitr, rmarkdown, profmem, flashier, ebnm
VignetteBuilder: knitr
NeedsCompilation: yes
Biarch: true
Remotes: stephens999/ashr, stephenslab/ebnm, willwerscheid/flashier
RoxygenNote: 7.2.3
Author: Matthew Stephens [aut],
  Sarah Urbut [aut],
  Gao Wang [aut],
  Yuxin Zou [aut],
  Yunqi Yang [ctb],
  Sam Roweis [cph],
  David Hogg [cph],
  Jo Bovy [cph],
  Peter Carbonetto [aut, cre]
Maintainer: Peter Carbonetto <peter.carbonetto@gmail.com>
Built: R 4.4.0; x86_64-apple-darwin18.7.0; 2024-06-02 08:06:26 UTC; unix
